@@ -180,11 +180,17 @@ def parser():
             for website_link in website_links:
                 direct_link = parser_direct_link(website_link)+'/'
                 log.debug(f'Parsing {direct_link}')
-                try:
-                    people_links = parser_people_links(direct_link)
-                except:
-                    people_links = None
-                    log.warning(f'Duplicate or non-templated html at -> {direct_link}')
+                i = 0
+                while i<3:
+                    try:
+                        people_links = parser_people_links(direct_link)
+                        i=4
+                    except:
+                        if i == 2 and (direct_link.find('perm') != -1 or direct_link.find('orenburg') != -1):
+                            return [{'code': 1, 'script': os.path.basename(__file__)}]
+                        people_links = None
+                        i+=1
+                        log.warning(f'Duplicate or non-templated html at -> {direct_link}')
                 if people_links != None:
                     for person_link in people_links:
                         if person_link != None:
@@ -204,14 +210,3 @@ def parser():
         return people
     else:
         return [{'code': 2, 'script': os.path.basename(__file__)}]
-
-
-if __name__ == '__main__':
-    #print(parser())
-    people_links = parser_people_links('http://13aas.arbitr.ru/')
-    for person_link in people_links:
-        if person_link != None:
-            person = parser_person(person_link, 'http://13aas.arbitr.ru/')
-            if person == 1:
-                print("\n\n\n\n\n\nA\n\n\n\n\n\n")
-            print(person)
\ No newline at end of file
