@@ -5,12 +5,9 @@ import logging
 import logging.handlers
 
 
+logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
-handler = logging.handlers.SysLogHandler(address='/dev/log')
-formatter = logging.Formatter(f'%(module)s.{__name__}: %(message)s')
-handler.setFormatter(formatter)
-log.addHandler(handler)
 
 
 HOST = 'https://ru.wikipedia.org'
@@ -51,7 +48,7 @@ def parser(URL, cont_id=1, cont_id_work=37):
     log.debug(f"The script {__name__} starts working")
     html = f.get_html(URL)
     if html.status_code == 200:
-        person = get_content(html,cont_id, cont_id_work)
+        person = get_content(html, cont_id, cont_id_work)
         if person == 1:
             return [{'code': 1, 'script': os.path.basename(__file__)}]
         content = []
